import argparse
import subprocess
from pathlib import Path



def generate_django_app(app_name):
    try:
        # Créer l'application Django en utilisant django-admin
        subprocess.run(["django-admin", "startapp", app_name], check=True)
        print(f"Django app '{app_name}' created successfully!")
        
        # Supprimer le fichier models.py
        models_file = Path.cwd() / app_name / "models.py"
        models_file.unlink()
        views_file = Path.cwd() / app_name / "views.py"
        views_file.unlink()

        # Créer un répertoire models
        models_dir = Path.cwd() / app_name / "models"
        views_dir = Path.cwd() / app_name / "views"
        models_dir.mkdir(exist_ok=True)
        views_dir.mkdir(exist_ok=True)
        print(f"Directory '{models_dir}' created successfully!")
        
        
        # Créer le fichier urls.py avec les URL patterns
        urls_file = Path.cwd() / app_name / "urls.py"
        if not urls_file.exists():
            with open(urls_file, 'w') as f:
                f.write("from django.urls import path\n")
                f.write("from . import views\n\n")
                f.write("urlpatterns = [\n")
                f.write("    path('', views.index, name='home'),\n")
                f.write("]\n")
            print(f"File '{urls_file}' created successfully!")


    except subprocess.CalledProcessError as e:
        print(f"Error occurred while creating Django app '{app_name}': {e}")
        return

def main():
    parser = argparse.ArgumentParser(description="Generate a Django app")
    parser.add_argument("app_name", help="Name of the Django app to create")
    args = parser.parse_args()

    generate_django_app(args.app_name)

if __name__ == "__main__":
    main()



import argparse
from pathlib import Path
import inflect
import re




field_widgets = {
    'DateField': "forms.DateInput(attrs={'class': 'form-control datepicker'})",
    'DateTimeField': "forms.DateTimeInput(attrs={'class': 'form-control datetimepicker'})",
    'CharField': "forms.TextInput(attrs={'class': 'form-control custom-text-input'})",
    'EmailField': "forms.EmailInput(attrs={'class': 'form-control custom-email-input'})",
    'BooleanField': "forms.CheckboxInput(attrs={'class': 'form-control custom-checkbox'})",
    'IntegerField': "forms.NumberInput(attrs={'class': 'form-control custom-number-input'})",
    'FloatField': "forms.NumberInput(attrs={'class': 'form-control custom-float-input'})",
    'URLField': "forms.URLInput(attrs={'class': 'form-control custom-url-input'})",
    'FileField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-file-input'})",
    'ImageField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-image-input'})",
    'TextField': "forms.Textarea(attrs={'class': 'form-control custom-textarea'})",
    'SlugField': "forms.TextInput(attrs={'class': 'form-control custom-slug-input'})",
    'ChoiceField': "forms.Select(attrs={'class': 'form-control custom-select'})",
    'ModelChoiceField': "forms.Select(attrs={'class': 'form-control custom-model-select'})",
    'TimeField': "forms.TimeInput(attrs={'class': 'form-control custom-time-input'})",
    'DecimalField': "forms.NumberInput(attrs={'class': 'form-control custom-decimal-input'})",
}

def get_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word)
    return plural_word

def get_lower_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word.lower())
    return plural_word

def copy_file(source_file, destination_file):
    try:
        with open(source_file, 'r') as source:
            with open(destination_file, 'w') as destination:
                content = source.read()
                destination.write(content)
        print(f"File copied from '{source_file}' to '{destination_file}' successfully.")
    except FileNotFoundError:
        print("File not found. Please provide valid file names.")

def parse_model_fields(file_path):
    field_pattern = re.compile(r'^\s*(\w+)\s*=\s*models\.(\w+)\(', re.MULTILINE)
    fields = {}

    with open(file_path, 'r') as file:
        content = file.read()
        matches = field_pattern.finditer(content)

        for match in matches:
            field_name = match.group(1)
            field_type = match.group(2)
            fields[field_name] = field_type

    return fields






def generate_view(app_name, model_name):
    # Chemin du dossier des vues dans l'application spécifiée
    views_folder = Path(f"{app_name}/views")

    if not views_folder.exists():
        views_folder.mkdir(parents=True)

    # Nom du fichier pour la vue
    view_filename = views_folder / f"{model_name}View.py"

    if view_filename.exists():
        user_input = input(f"Le fichier '{view_filename}' existe déjà. Voulez-vous l'écraser ? (O/n): ")
        if user_input.lower() != 'o':
            print("Annulation de la création de la vue.")
            return

    # Génération du contenu de la vue Django
    view_content = f"from {app_name}.models import {model_name}\n"
    view_content += f"from django.shortcuts import render, get_object_or_404, redirect\n"
    view_content += f"from django.core.paginator import Paginator, PageNotAnInteger, EmptyPage\n"
    view_content += f"from django.contrib import messages\n"
    view_content += f"from {app_name}.forms.{model_name}Form import {model_name}Form\n\n"
    view_content += f"def index(request):\n"
    view_content += f"    {get_plural(model_name.lower())}_list = {model_name}.objects.all()\n"
    view_content += f"    paginator = Paginator({get_plural(model_name.lower())}_list, 8)\n"
    view_content += f"    page = request.GET.get('page', 1)\n\n"
    view_content += f"    try:\n"
    view_content += f"        {get_plural(model_name.lower())} = paginator.page(page)\n"
    view_content += f"    except PageNotAnInteger:\n"
    view_content += f"        {get_plural(model_name.lower())} = paginator.page(1)\n"
    view_content += f"    except EmptyPage:\n"
    view_content += f"        {get_plural(model_name.lower())} = paginator.page(paginator.num_pages)\n"
    view_content += f"    except:\n"
    view_content += f"        {get_plural(model_name.lower())} = paginator.page(1)\n\n"
    view_content += f"    return render(request, '{app_name}/{get_plural(model_name.lower())}/{model_name.lower()}_index.html', {{'{get_plural(model_name.lower())}': {get_plural(model_name.lower())}}})\n\n"
    view_content += f"# Les autres fonctions comme show, create, update, delete... \n"
    view_content += f"def show(request, id):\n"
    view_content += f"    {model_name.lower()} = get_object_or_404({model_name}, id=id)\n"
    view_content += f"    return render(request, '{app_name}/{get_plural(model_name.lower())}/{model_name.lower()}_show.html', {{'{model_name.lower()}': {model_name.lower()}}})\n\n"

    view_content += f"def create(request):\n"
    view_content += f"    if request.method == 'POST':\n"
    view_content += f"        form = {model_name}Form(request.POST, request.FILES)\n"
    view_content += f"        if form.is_valid():\n"
    view_content += f"            form.save()\n"
    view_content += f"            messages.success(request, '{model_name} has been saved !')\n"
    view_content += f"            return redirect('{model_name.lower()}_index')\n"
    view_content += f"    else:\n"
    view_content += f"        form = {model_name}Form()\n"
    view_content += f"    return render(request, '{app_name}/{get_plural(model_name.lower())}/{model_name.lower()}_new.html', {{'form': form}})\n\n"
    
    view_content += f"def update(request, id):\n"
    view_content += f"    {model_name.lower()} = get_object_or_404({model_name}, id=id)\n\n"
    view_content += f"    if request.method == 'POST':\n"
    view_content += f"        if request.POST.get('_method') == 'PUT':\n"
    view_content += f"            form = {model_name}Form(request.POST, request.FILES, instance={model_name.lower()})\n"
    view_content += f"            if form.is_valid():\n"
    view_content += f"                form.save()\n"
    view_content += f"                messages.success(request, '{model_name} has been updated !')\n"
    view_content += f"                return redirect('{model_name.lower()}_index')\n"
    view_content += f"        else:\n"
    view_content += f"            form = {model_name}Form(instance={model_name.lower()})\n"
    view_content += f"    else:\n"
    view_content += f"        form = {model_name}Form(instance={model_name.lower()})\n"
    view_content += f"    return render(request, '{app_name}/{get_plural(model_name.lower())}/{model_name.lower()}_new.html', {{'form': form, '{model_name.lower()}': {model_name.lower()}}})\n\n"

    view_content += f"def delete(request, id):\n"
    view_content += f"    {model_name.lower()} = get_object_or_404({model_name}, id=id)\n"
    view_content += f"    if request.method == 'POST':\n"
    view_content += f"        if request.POST.get('_method') == 'DELETE':\n"
    view_content += f"            {model_name.lower()}.delete()\n"
    view_content += f"            messages.success(request, '{model_name} has been deleted !')\n"
    view_content += f"    return redirect('{model_name.lower()}_index')\n\n"
    

    # Écriture du contenu dans le fichier de la vue
    with open(view_filename, "w") as view_file:
        view_file.write(view_content)

    print(f"La vue {model_name}View a été créée dans {views_folder} !")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Générer une vue Django pour un modèle.")
    parser.add_argument("app_name", help="Nom de l'application dans laquelle vous souhaitez générer la vue.")
    parser.add_argument("model_name", help="Nom du modèle pour lequel vous souhaitez générer la vue.")
    args = parser.parse_args()

    try:
        generate_view(model_name=args.model_name, app_name=args.app_name)
    except LookupError:
        print("L'application spécifiée est introuvable.")



import argparse
import subprocess
from pathlib import Path




def check_django_installation():
    try:
        # Vérifier l'installation de Django en tentant d'importer le module
        import django
        return True
    except ImportError:
        return False

def install_django():
    try:
        subprocess.run(["pip", "install", "django"], check=True)
        return True
    except subprocess.CalledProcessError:
        return False

def create_django_project(project_name):
    # Vérifier si Django est installé, sinon l'installer
    if not check_django_installation():
        print("Django not found. Installing Django...")
        if not install_django():
            print("Failed to install Django. Aborting project creation.")
            return

    try:
        # Création du répertoire pour le projet
        project_dir = Path.cwd() / project_name
        project_dir.mkdir(parents=True, exist_ok=True)

        # Création du projet Django dans le répertoire spécifié
        subprocess.run(["django-admin", "startproject", "config", str(project_dir)], check=True)
        print(f"Project '{project_name}' created successfully in '{project_dir}'!")

        # Configuration des paramètres dans settings.py
        BASE_DIR = Path.cwd() / project_name
        settings_file = BASE_DIR / 'config' / 'settings.py'

        if settings_file.exists():
            STATIC = "static"
            MEDIA_ROOT = "media"
            
            with open(settings_file, 'a') as f:
                f.write(f"\n\n# Added by script\n")
                f.write(f"STATIC_URL = '/{STATIC}/'\n")
                f.write(f"STATICFILES_DIRS = [BASE_DIR / '{STATIC}']\n")
                f.write(f"MEDIA_URL = '/media/'\n")
                f.write(f"MEDIA_ROOT = BASE_DIR / '{MEDIA_ROOT}'\n")

    except subprocess.CalledProcessError as e:
        print(f"Error occurred while creating project '{project_name}': {e}")
        return

def main():
    parser = argparse.ArgumentParser(description="Create a Django project")
    parser.add_argument("project_name", help="Name of the Django project to create")
    args = parser.parse_args()

    create_django_project(args.project_name)

if __name__ == "__main__":
    main()



import inflect
import re


field_widgets = {
    'DateField': "forms.DateInput(attrs={'class': 'form-control datepicker'})",
    'DateTimeField': "forms.DateTimeInput(attrs={'class': 'form-control datetimepicker'})",
    'CharField': "forms.TextInput(attrs={'class': 'form-control custom-text-input'})",
    'EmailField': "forms.EmailInput(attrs={'class': 'form-control custom-email-input'})",
    'BooleanField': "forms.CheckboxInput(attrs={'class': 'form-control custom-checkbox'})",
    'IntegerField': "forms.NumberInput(attrs={'class': 'form-control custom-number-input'})",
    'FloatField': "forms.NumberInput(attrs={'class': 'form-control custom-float-input'})",
    'URLField': "forms.URLInput(attrs={'class': 'form-control custom-url-input'})",
    'FileField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-file-input'})",
    'ImageField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-image-input'})",
    'TextField': "forms.Textarea(attrs={'class': 'form-control custom-textarea'})",
    'SlugField': "forms.TextInput(attrs={'class': 'form-control custom-slug-input'})",
    'ChoiceField': "forms.Select(attrs={'class': 'form-control custom-select'})",
    'ModelChoiceField': "forms.Select(attrs={'class': 'form-control custom-model-select'})",
    'TimeField': "forms.TimeInput(attrs={'class': 'form-control custom-time-input'})",
    'DecimalField': "forms.NumberInput(attrs={'class': 'form-control custom-decimal-input'})",
}

def get_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word)
    return plural_word

def get_lower_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word.lower())
    return plural_word

def copy_file(source_file, destination_file):
    try:
        with open(source_file, 'r') as source:
            with open(destination_file, 'w') as destination:
                content = source.read()
                destination.write(content)
        print(f"File copied from '{source_file}' to '{destination_file}' successfully.")
    except FileNotFoundError:
        print("File not found. Please provide valid file names.")

def parse_model_fields(file_path):
    field_pattern = re.compile(r'^\s*(\w+)\s*=\s*models\.(\w+)\(', re.MULTILINE)
    fields = {}

    with open(file_path, 'r') as file:
        content = file.read()
        matches = field_pattern.finditer(content)

        for match in matches:
            field_name = match.group(1)
            field_type = match.group(2)
            fields[field_name] = field_type

    return fields



import argparse
import subprocess
import pathlib
from pathlib import Path





# The directory containing this file
BASE_DIR = pathlib.Path(__file__).parent.parent




def start(file_path, args):
    subprocess.run(["python", Path(BASE_DIR / file_path ), args.app_name, args.model_name])


    
def make_project(args):
    print(f"Executing create:project command for {args.project_name}")
    # generate_entity()
    subprocess.run(["python", 
                    Path(BASE_DIR / "package/create_django_project.py" ), 
                    args.project_name])
    
def make_app(args):
    print(f"Executing create:app command for app: {args.app_name}.")
    # generate_entity()
    subprocess.run(["python", 
                    Path(BASE_DIR / "package/generate_django_app.py" ), 
                    args.app_name])
    
def make_entity(args):
    print(f"Executing make:entity command for app: {args.app_name} and model: {args.model_name}.")
    # generate_entity()
    start("package/model_generator.py", args)
    start("package/view_generator.py", args)
    start("package/template_generator.py", args)

def make_form(args):
    print(f"Executing make:form command for app: {args.app_name} and model: {args.model_name}")
    start("package/form_generator.py", args)

def make_view(args):
    print(f"Executing make:view command for app: {args.app_name} and model: {args.model_name}")
    start("package/view_generator.py", args)
    start("package/template_generator.py", args)
    
def make_model(args):
    print(f"Executing make:model command for app: {args.app_name} and model: {args.model_name}")
    start("package/model_generator.py", args)

def make_entity_crud(args):
    print(f"Executing make:crud command for app: {args.app_name} and model: {args.model_name}.")
    start("package/from_generator.py", args)
    start("package/view_generator.py", args)
    start("package/template_generator.py", args)
    
def make_service(args):
    print(f"Executing make:service command for app: {args.app_name} and service: {args.service_name}.")
 
    subprocess.run(["python", 
                    Path(BASE_DIR / "package/ecommerce_generator.py" ), 
                    args.app_name, args.service_name])

def main():
    parser = argparse.ArgumentParser(description="Custom CLI for performing tasks")
    subparsers = parser.add_subparsers()

    entity_parser = subparsers.add_parser("create:project", help="Create an django project")
    entity_parser.add_argument("project_name", help="Name of the project")
    entity_parser.set_defaults(func=make_project)
    
    entity_parser = subparsers.add_parser("create:app", help="Create an django application")
    entity_parser.add_argument("app_name", help="Name of the app")
    entity_parser.set_defaults(func=make_app)

    entity_parser = subparsers.add_parser("make:entity", help="Create an entity")
    entity_parser.add_argument("app_name", help="Name of the app")
    entity_parser.add_argument("model_name", help="Name of the model")
    entity_parser.set_defaults(func=make_entity)

    form_parser = subparsers.add_parser("make:form", help="Create a form")
    form_parser.add_argument("app_name", help="Name of the app")
    form_parser.add_argument("model_name", help="Name of the model")
    form_parser.set_defaults(func=make_form)
    
    model_parser = subparsers.add_parser("make:model", help="Create a model")
    model_parser.add_argument("app_name", help="Name of the app")
    model_parser.add_argument("model_name", help="Name of the model")
    model_parser.set_defaults(func=make_model)
    
    view_parser = subparsers.add_parser("make:view", help="Create a view")
    view_parser.add_argument("app_name", help="Name of the app")
    view_parser.add_argument("model_name", help="Name of the model")
    view_parser.set_defaults(func=make_view)

    entity_crud_parser = subparsers.add_parser("make:crud", help="Create CRUD for an entity")
    entity_crud_parser.add_argument("app_name", help="Name of the app")
    entity_crud_parser.add_argument("model_name", help="Name of the model")
    entity_crud_parser.set_defaults(func=make_entity_crud)
    
    service_parser = subparsers.add_parser("make:service", help="Generate a Django e-commerce services")
    service_parser.add_argument("app_name", help="Name of the app")
    service_parser.add_argument("service_name", help="Name of the service")
    service_parser.set_defaults(func=make_service)

    args = parser.parse_args()
    if hasattr(args, 'func'):
        args.func(args)


if __name__ == "__main__":
    main()


# model_generator.py
import argparse
import questionary
from django.db import models
from pathlib import Path
import re




# Dictionnaire des types de champs Django correspondant aux choix possibles
field_choices = {
    "string": 'models.CharField',
    "integer": 'models.IntegerField',
    "text": 'models.TextField',
    "boolean": "models.BooleanField",
    "date": "models.DateField",
    "datetime": "models.DateTimeField",
    "email": "models.EmailField",
    "float": "models.FloatField",
    "decimal": "models.DecimalField",
    "file": "models.FileField",
    "image": "models.ImageField",
    "slug": "models.SlugField",
    "url": "models.URLField",
    "duration": "models.DurationField",
    "uuid": "models.UUIDField",
    "biginteger": "models.BigIntegerField",
    "positiveinteger": "models.PositiveIntegerField",
    "positivebiginteger": "models.PositiveBigIntegerField",
    "binary": "models.BinaryField",
    "smallinteger": "models.SmallIntegerField",
    "time": "models.TimeField",
    "genericip": "models.GenericIPAddressField",
    "foreignkey": 'models.ForeignKey',
    "relation": 'relation'
    # Ajoutez d'autres types de champs ici
}

def is_valid_model_name(name):
    return bool(re.match(r'^[a-zA-Z][_a-zA-Z0-9]*$', name))

def parse_model_fields(file_path):
    field_pattern = re.compile(r'^\s*(\w+)\s*=\s*models\.(\w+)\(', re.MULTILINE)
    fields = {}

    with open(file_path, 'r') as file:
        content = file.read()
        matches = field_pattern.finditer(content)

        for match in matches:
            field_name = match.group(1)
            field_type = match.group(2)
            fields[field_name] = field_type

    return fields

def generate_model(app_name, model_name = False):
    # model_name = ""
    # print("===================   {app_name} : {model_name}   ===================")
    fields = [('updated_at', 'models.DateTimeField(auto_now=True)', {}),
              ('created_at', 'models.DateTimeField(auto_now_add=True)', {})]
    if not model_name:
        while True:
            model_name = questionary.text("Nom du modèle :").ask().strip()
            if not model_name:
                print("Le nom du modèle ne peut pas être vide. Veuillez saisir un nom valide.")
            elif not is_valid_model_name(model_name):
                print("Le nom du modèle n'est pas valide. Veuillez utiliser un nom de classe Python valide.")
            else:
                break
   
        
        
    model_folder = f"{app_name}/models"
    model_folder_path = Path(model_folder)

    if not model_folder_path.exists():
        model_folder_path.mkdir(parents=True)

    # Nom du fichier pour le modèle
    model_filename = f"{model_folder}/{model_name.capitalize()}.py"
    model_file_path = Path(model_filename)
    
    if model_file_path.exists():
        old_fields = parse_model_fields(model_file_path)
        # print("==== fields =====")
        # print(old_fields)
        print(f"Le fichier '{model_filename}' existe déjà. Ajouter des champs")
        

        

    while True:
        field_name = questionary.text("Nom du champ (laissez vide pour terminer) :").ask()
        if not field_name:
            break

        field_type = questionary.text("Type du champ (tapez '?' pour voir la liste des types, appuyez sur Entrée pour 'string') :").ask().strip()
        while field_type not in field_choices and field_type != "":
            if field_type == '?':
                print("Types disponibles : ", ', '.join(field_choices.keys()))
            else:
                print("Types disponibles : ", ', '.join(field_choices.keys()))
            field_type = questionary.text("Type du champ (tapez '?' pour voir la liste des types, appuyez sur Entrée pour 'string') :").ask().strip()
 
        if field_type == "":
            field_type = "string"  # Utiliser 'string' par défaut si le type n'est pas valide
        elif field_type in field_choices:
            field_type = field_type
        else:
            if field_type == 'relation':
                related_model = questionary.text("Nom du modèle lié :").ask().strip()
                relationship_type = questionary.select("Type de relation :", choices=["OneToOne", "OneToMany", "ManyToOne", "ManyToMany"]).ask().strip()

                if relationship_type == "OneToOne":
                    fields.append((field_name, f"models.OneToOneField('{related_model}')", {'on_delete': 'models.CASCADE'}))
                elif relationship_type == "OneToMany":
                    fields.append((field_name, f"models.ForeignKey('{related_model}', related_name='{field_name}_set')", {'on_delete': 'models.CASCADE'}))
                elif relationship_type == "ManyToOne":
                    fields.append((field_name, f"models.ForeignKey('{related_model}')", {'on_delete': 'models.CASCADE'}))
                elif relationship_type == "ManyToMany":
                    fields.append((field_name, f"models.ManyToManyField('{related_model}')", {}))
            else:
                fields.append((field_name, field_choices[field_type], {}))
                
        
        null_choice = questionary.confirm("Le champ peut-il être null ?").ask()
            
     
        # Ajouter le champ avec le type et la propriété null appropriés à la liste des champs
        fields.append((field_name, field_choices[field_type], {'blank':null_choice, 'null':null_choice}))

  
    
    if model_file_path.exists():
        # Lire le fichier existant pour extraire les champs
        with open(model_filename, "r") as model_file:
            existing_code = model_file.read()

        # Extraire les noms des champs existants
        existing_fields = [line.strip().split()[0] for line in existing_code.splitlines() if line.strip().startswith(model_name.capitalize())]
        # print((existing_fields,))

        # Vérifier les nouveaux champs par rapport aux champs existants
        fields_to_add = [(field_name, field_type, field_options) for field_name, field_type, field_options in fields if field_name not in existing_fields]

       
        # Ajouter les nouveaux champs 'created_at' et 'updated_at
        if fields_to_add:
            with open(model_filename, "a") as model_file:
                last = []
                for field_name, field_type, field_options in fields_to_add:
                    if field_name == "updated_at" or field_name == "created_at":
                        last.append((field_name, field_type, field_options))
                        continue
                    options_string = ', '.join([f"{key}={value}" for key, value in field_options.items()])
                    if field_type == "models.CharField" :
                        model_file.write(f"    {field_name} = {field_type}(max_length=60, {options_string})\n")
                    else:
                        model_file.write(f"    {field_name} = {field_type}({options_string})\n")
                    

        print(f"Le modèle {model_name.capitalize()} a été mis à jour avec de nouveaux champs dans {model_filename} !")
    else:
        # ... Code pour créer le modèle s'il n'existe pas encore ...
        model_code = f"from django.db import models\n\n"
        model_code += f"class {model_name.capitalize()}(models.Model):\n"
        
        # Enregistrez le code du modèle dans un fichier spécifique
        with open(model_filename, "w") as model_file:
            model_file.write(model_code)
        
        fields_to_add = [(field_name, field_type, field_options) for field_name, field_type, field_options in fields]

       
        # Ajouter les  champs 
        if fields_to_add:
            with open(model_filename, "a") as model_file:
                last = []
                for field_name, field_type, field_options in fields_to_add:
                    if field_name == "updated_at" or field_name == "created_at":
                        last.append((field_name, field_type, field_options))
                        continue
                    options_string = ', '.join([f"{key}={value}" for key, value in field_options.items()])
                    model_file.write(f"    {field_name} = {field_type}({options_string})\n")
                    
                for field_name, field_type, field_options in last:
                    model_file.write(f"    {field_name} = {field_type}\n")
                
        print(f"Le modèle {model_name.capitalize()} a été créé dans {model_filename} !")
    # print(f"Le modèle {model_name.capitalize()} a été créé dans {model_filename} !")

def main():
    parser = argparse.ArgumentParser(description="Générer un modèle Django interactif.")
    parser.add_argument("app_name", help="Nom de l'application dans laquelle vous souhaitez générer le dossier models.")
    parser.add_argument("model_name", help="Nom du model que vous souhaitez créer.")
    parser.add_argument("-v", "--version", action="version", version="%(prog)s 1.0")
    args = parser.parse_args()

    generate_model(app_name=args.app_name, model_name=args.model_name)
    
if __name__ == "__main__":
    main()


import argparse
import subprocess
from pathlib import Path
import os



def getCart(app_name):
    return '''
from django.contrib import messages
from '''+app_name+'''.models import Carrier, Setting, Product  # Importez vos modèles ici

class CartService:
    @staticmethod
    def add_to_cart(request, product_id, quantity):
        cart = request.session.get('cart', {})
        product_id = str(product_id)
        
        if product_id in cart:
            cart[product_id] += quantity
        else:
            cart[product_id] = quantity
        
        request.session['cart'] = cart
        messages.success(request, f"Produit ajouté au panier.")
    
    @staticmethod
    def remove_from_cart(request, product_id, quantity):
        cart = request.session.get('cart', {})
        product_id = str(product_id)
        
        if product_id in cart:
            if cart[product_id] <= quantity:
                del cart[product_id]
            else:
                cart[product_id] -= quantity
        
        request.session['cart'] = cart
        messages.success(request, f"Produit supprimé du panier.")
    
    @staticmethod
    def clear_cart(request):
        request.session.pop('cart', None)
        messages.success(request, f"Le panier a été vidé.")
    
    @staticmethod
    def get_cart_details(request):
        cart = request.session.get('cart', {})
        setting = Setting.objects.first()
        tax_rate = setting.taxe_rate / 100 if setting else 0
        
        result = {
            'items': [],
            'sub_total': 0,
            'carrier_name': 0,
            'shipping_price': 0,
            'taxe_amount': 0,
            'sub_total_ht': 0,
            'sub_total_ttc': 0,
            'sub_total_with_shipping': 0,
            'cart_count': 0,
        }
        carrier = request.session.get('carrier')
        if not carrier:
            carrier = Carrier.objects.first()
        
        for product_id, quantity in cart.items():
            product = Product.objects.filter(id=product_id).first()
            
            if product:
                sub_total = product.solde_price * quantity
                result['items'].append({
                    'product': {
                        'id': product.id,
                        'slug': product.slug,
                        'name': product.name,
                        'description': product.description,
                        'solde_price': product.solde_price,
                        'regular_price': product.regular_price,
                        # Ajoutez d'autres attributs du produit ici
                    },
                    'quantity': quantity,
                    'sub_total': round(sub_total, 2),
                    'taxe_amount': round(sub_total / (1 + tax_rate) * tax_rate, 2),
                    'sub_total_ht': round(sub_total / (1 + tax_rate), 2),
                    'sub_total_ttc': round(sub_total, 2),
                })
                result['sub_total'] += round(sub_total, 2)
                result['cart_count'] += quantity
        
        result['carrier_name'] = carrier.name
        result['shipping_price'] = round(carrier.price, 2)
        result['taxe_amount'] = round(result['sub_total'] / (1 + tax_rate) * tax_rate, 2)
        result['sub_total_ht'] = round(result['sub_total'] / (1 + tax_rate), 2)
        result['sub_total_ttc'] = round(result['sub_total'], 2)
        result['sub_total_with_shipping'] = round(result['sub_total'] + carrier.price, 2)
        
        return result


    '''


def getWishlist(app_name):
    return '''
from '''+app_name+'''.models import Product  # Importez votre modèle Product ici

class WishService:
    @staticmethod
    def add_product_to_wish(request, product_id):
        wish_products = request.session.get('wish', [])

        if product_id not in wish_products:
            wish_products.append(product_id)
            request.session['wish'] = wish_products

    @staticmethod
    def remove_product_from_wish(request, product_id):
        wish_products = request.session.get('wish', [])

        if product_id in wish_products:
            wish_products.remove(product_id)
            request.session['wish'] = wish_products

    @staticmethod
    def get_wished_products(request):
        return request.session.get('wish', [])

    @staticmethod
    def get_wished_products_details(request):
        wish_products = request.session.get('wish', [])
        wished_details = []

        for product_id in wish_products:
            product = Product.objects.filter(id=product_id).first()

            if product:
                wished_details.append({
                    'id': product.id,
                    'slug': product.slug,
                    'name': product.name,
                    'description': product.description,
                    'solde_price': product.solde_price,
                    'regular_price': product.regular_price,  # Typo corrected: 'solde_price'
                    'images': product.images,
                    'stock': product.stock,
                    # Ajoutez d'autres attributs du produit ici
                })

        return wished_details

    @staticmethod
    def clear_wished_products(request):
        request.session.pop('wish', None)

    '''


def getCompare(app_name):
    return '''
from '''+app_name+'''.models import Product  # Importez votre modèle Product ici

class CompareService:
    @staticmethod
    def add_product_to_compare(request, product_id):
        compare_products = request.session.get('compare', [])

        if product_id not in compare_products:
            compare_products.append(product_id)
            request.session['compare'] = compare_products

    @staticmethod
    def remove_product_from_compare(request, product_id):
        compare_products = request.session.get('compare', [])

        if product_id in compare_products:
            compare_products.remove(product_id)
            request.session['compare'] = compare_products

    @staticmethod
    def get_compared_products(request):
        return request.session.get('compare', [])

    @staticmethod
    def get_compared_products_details(request):
        compare_products = request.session.get('compare', [])
        compared_details = []

        for product_id in compare_products:
            product = Product.objects.filter(id=product_id).first()

            if product:
                compared_details.append({
                    'id': product.id,
                    'slug': product.slug,
                    'name': product.name,
                    'description': product.description,
                    'solde_price': product.solde_price,
                    'regular_price': product.sodePrice,  # Typo corrected: 'solde_price'
                    'images': product.images,
                    'stock': product.stock,
                    # Ajoutez d'autres attributs du produit ici
                })

        return compared_details

    @staticmethod
    def clear_compared_products(request):
        request.session.pop('compare', None)

    '''

def getStripe(app_name):
    return '''
from '''+app_name+'''.models import Method
from django.conf import settings

class StripeService:
    def __init__(self):
        # Vérifie si la méthode Stripe est disponible
        self.method = Method.objects.filter(name='Stripe').first()

    # Implémentez ici la logique de votre service
    def get_public_key(self):
        if self.method:
            return self.method.prod_public_key if settings.DEBUG else self.method.test_public_key
        return None  # Gérer le cas où la méthode n'est pas trouvée en base de données

    def get_private_key(self):
        if self.method:
            return self.method.prod_private_key if settings.DEBUG else self.method.test_private_key
        return None  # Gérer le cas où la méthode n'est pas trouvée en base de données

    '''
  

def generate_django_services(app_name, service_name):
    services = {
        'cart': getCart,
        'wish': getWishlist,
        'compare': getCompare,
        'payment': getStripe,
    }
    data_path = f"{app_name}/services/"
    data_file_path = f"{data_path}{service_name}_service.py"
    
    if not os.path.exists(data_path):
        os.makedirs(data_path)
        print(f"Dossier '{data_path}' créé.")

    if os.path.exists(data_file_path):
        print(f"Le fichier '{data_file_path}' existe déjà.")
        return
    
    if service_name not in services:
        print(f"Le service '{service_name}' n'est pas pris en charge.")
        return
    
    try:
        with open(data_file_path, 'w') as file:
            data = services[service_name](app_name)
            file.write(data)
            print(f"Service '{service_name}' pour l'application '{app_name}' a été créé avec succès.")
    except Exception as e:
        print(f"Une erreur est survenue lors de la création du service '{service_name}' pour l'application '{app_name}':")
        print(e)
        

def main():
    parser = argparse.ArgumentParser(description="Generate a Django Services")
    parser.add_argument("app_name", help="Name of the Django app to create")
    parser.add_argument("service_name", help="Name of the Django service to create")
    args = parser.parse_args()

    generate_django_services(args.app_name, args.service_name)

if __name__ == "__main__":
    main()


import argparse
from pathlib import Path
import inflect
import re





field_widgets = {
    'DateField': "forms.DateInput(attrs={'class': 'form-control datepicker'})",
    'DateTimeField': "forms.DateTimeInput(attrs={'class': 'form-control datetimepicker'})",
    'CharField': "forms.TextInput(attrs={'class': 'form-control custom-text-input'})",
    'EmailField': "forms.EmailInput(attrs={'class': 'form-control custom-email-input'})",
    'BooleanField': "forms.CheckboxInput(attrs={'class': 'form-control custom-checkbox'})",
    'IntegerField': "forms.NumberInput(attrs={'class': 'form-control custom-number-input'})",
    'FloatField': "forms.NumberInput(attrs={'class': 'form-control custom-float-input'})",
    'URLField': "forms.URLInput(attrs={'class': 'form-control custom-url-input'})",
    'FileField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-file-input'})",
    'ImageField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-image-input'})",
    'TextField': "forms.Textarea(attrs={'class': 'form-control custom-textarea'})",
    'SlugField': "forms.TextInput(attrs={'class': 'form-control custom-slug-input'})",
    'ChoiceField': "forms.Select(attrs={'class': 'form-control custom-select'})",
    'ModelChoiceField': "forms.Select(attrs={'class': 'form-control custom-model-select'})",
    'TimeField': "forms.TimeInput(attrs={'class': 'form-control custom-time-input'})",
    'DecimalField': "forms.NumberInput(attrs={'class': 'form-control custom-decimal-input'})",
}

def get_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word)
    return plural_word

def get_lower_plural(word):
    p = inflect.engine()
    plural_word = p.plural(word.lower())
    return plural_word

def copy_file(source_file, destination_file):
    try:
        with open(source_file, 'r') as source:
            with open(destination_file, 'w') as destination:
                content = source.read()
                destination.write(content)
        print(f"File copied from '{source_file}' to '{destination_file}' successfully.")
    except FileNotFoundError:
        print("File not found. Please provide valid file names.")

def parse_model_fields(file_path):
    field_pattern = re.compile(r'^\s*(\w+)\s*=\s*models\.(\w+)\(', re.MULTILINE)
    fields = {}

    with open(file_path, 'r') as file:
        content = file.read()
        matches = field_pattern.finditer(content)

        for match in matches:
            field_name = match.group(1)
            field_type = match.group(2)
            fields[field_name] = field_type

    return fields


def create_view_paginator(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    model_filename = f"{app_name}/models/{model_name}.py"
    model_fields = parse_model_fields(model_filename)
    
    

        
    index_content = '''
                    {% if datas.has_other_pages %}
                        <nav aria-label="Page navigation example">
                            <ul class="pagination">
                                {% if datas.has_previous %}
                                    <li class="page-item">
                                        <a href="?page={{ datas.previous_page_number }}" class="page-link" href="#">Previous</a>
                                    </li>
                                {% else %}
                                    <li class="page-item disabled">
                                        <span class="page-link">Previous</span>
                                    </li>
                                    
                                {% endif %}
                                
                            
                                {% for page in datas.paginator.page_range %}
                                    {% if  page >= datas.number|add:'-2' and page <= datas.number|add:'2'  %}
                                        <li class="page-item">
                                            <a href="?page={{page}}" class="page-link {% if datas.number == page %} active {% endif %}">{{ page }}</a>
                                        </li>
                                    {% endif %}
                                    
                                {% endfor %}

                                {% if datas.has_next %}
                                    <li class="page-item">
                                        <a href="?page={{ datas.next_page_number }}" class="page-link">Next</a>
                                    </li>
                                {% else %}
                                    <li class="page-item disabled">
                                        <span class="page-link">Next</span>
                                    </li>
                                    
                                {% endif %}
                            </ul>
                        </nav>
                        <p>
                            {{ datas.number }} of {{ datas.paginator.num_pages }}
                        </p>
                        {% endif %}
                        '''

    with open(template_folder / "paginator.html", "w") as index_file:
        index_file.write(index_content)
     
def create_view_index(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    model_filename = f"{app_name}/models/{model_name}.py"
    model_fields = parse_model_fields(model_filename)
    
    table_header = ""
    for key, value in model_fields.items():
        table_header += f"    <th scope='col'>{key}</td>\n"
     
    table_content = ""
    for key, value in model_fields.items():
        table_content += "    <td scope='col'>{{ "+ model_name.lower() +"."+key + "}}</td>\n"
        
    table_content += f'''<td>
                        <a href="{{% url '{model_name.lower()}_view' {model_name.lower()}.id %}}" class="btn btn-success">View</a>
                        <a href="{{% url '{model_name.lower()}_edit' {model_name.lower()}.id %}}" class="btn btn-primary">Edit</a>
                        <form action="{{% url '{model_name.lower()}_delete' {model_name.lower()}.id %}}" method="post">
                            {{% csrf_token %}}
                            <input type="hidden" name="_method" value="DELETE">
                            <button class="btn btn-danger">Delete</button>
                        </form>
                    </td>'''

        
    index_content = '''{% extends "''' + app_name + '''/admin.html" %}
    {% load static %}

    {% block content %}

    {% include "''' + app_name + '''/admin/paginator.html" with datas=''' + get_lower_plural(model_name) + ''' %}
    {% if messages %}
        {% for message in messages %}
            <div class="alert alert-success">
                {{ message }}
            </div>
        {% endfor %}
    {% endif %}
    <div class="d-flex my-2 justify-content-end">
        <a href="{% url ''' + model_name.lower() + ''' %}" class="btn btn-success">Create '''+model_name+'''</a>
    </div>
    <table class="table table-bordered">
        <thead>
            <tr>
                <td scope="col">#</td>
                ''' + table_header + '''
                <th scope="col">Actions</th>
            </tr>
        </thead>
        <tbody>

            {% for ''' + model_name.lower() + ''' in ''' + get_lower_plural(model_name) + ''' %}
                <td scope="col">{{ ''' + model_name.lower() + '''.id }}</td>
                ''' + table_content + '''
            {% endfor %}

        </tbody>
    </table>
    {% include "blog/components/paginator.html" with datas=''' + get_lower_plural(model_name) + ''' %}


    {% endblock %}'''

    with open(template_folder / f"{model_name.lower()}_index.html", "w") as index_file:
        index_file.write(index_content)
     
def create_view_show(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    model_filename = f"{app_name}/models/{model_name}.py"
    model_fields = parse_model_fields(model_filename)
    
    table_content = ""
    for key, value in model_fields.items():
        table_content += "    <tr>\n"
        table_content += "        <td scope='col'> "+key.capitalize() + ": </td>\n"
        table_content += "        <td scope='col'>{{ "+ model_name.lower() +"."+key + "}}</td>"
        table_content += "    </tr>"
        
    

        
    index_content = '''{% extends "''' + app_name + '''/admin.html" %}
    {% load static %}

    {% block content %}

    {% include "''' + app_name + '''/admin/paginator.html" with datas=''' + get_lower_plural(model_name) + ''' %}
    {% if messages %}
        {% for message in messages %}
            <div class="alert alert-success">
                {{ message }}
            </div>
        {% endfor %}
    {% endif %}
    <div class="d-flex my-2 justify-content-end">
        <a href="{% url ''' + model_name.lower() + ''' %}" class="btn btn-success">Create '''+model_name+'''</a>
    </div>
    <table class="table table-bordered">
        <tbody>

            ''' + table_content + '''

        </tbody>
    </table>
    {% include "blog/components/paginator.html" with datas=''' + get_lower_plural(model_name) + ''' %}


    {% endblock %}'''

    with open(template_folder / f"{model_name.lower()}_show.html", "w") as index_file:
        index_file.write(index_content)
     
def create_view_edit(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    form_link = f"{model_name.lower()}_form.html"
    # model_filename = f"{app_name}/models/{model_name}.py"
    # model_fields = parse_model_fields(model_filename)
    

        
    index_content = '''{% extends "''' + app_name + '''/admin.html" %}
    {% load static %}

    {% block content %}
    
    {% if messages %}
        {% for message in messages %}
            <div class="alert alert-success">
                {{ message }}
            </div>
        {% endfor %}
    {% endif %}
    
    <div class="d-flex my-2 justify-content-end">
        <a href="{% url ''' + model_name.lower() + ''' %}" class="btn btn-success">Edit '''+model_name+'''</a>
    </div>
    
    {% include "''' + form_link + '''" with ''' + model_name.lower() + '''=''' + model_name.lower() + ''' %}


    {% endblock %}'''

    with open(template_folder / f"{model_name.lower()}_edit.html", "w") as index_file:
        index_file.write(index_content)
     
def create_view_create(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    form_link = f"{model_name.lower()}_form.html"
    # model_filename = f"{app_name}/models/{model_name}.py"
    # model_fields = parse_model_fields(model_filename)
    

        
    index_content = '''{% extends "''' + app_name + '''/admin.html" %}
    {% load static %}

    {% block content %}
    
    {% if messages %}
        {% for message in messages %}
            <div class="alert alert-success">
                {{ message }}
            </div>
        {% endfor %}
    {% endif %}
    
    <div class="d-flex my-2 justify-content-end">
        <a href="{% url ''' + model_name.lower() + ''' %}" class="btn btn-success">Create '''+model_name+'''</a>
    </div>
    
    {% include "''' + form_link + '''" with ''' + model_name.lower() + '''=''' + model_name.lower() + ''' %}


    {% endblock %}'''

    with open(template_folder / f"{model_name.lower()}_create.html", "w") as index_file:
        index_file.write(index_content)
     
def create_view_form(model_name, app_name):
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")
    model_filename = f"{app_name}/models/{model_name}.py"
    model_fields = parse_model_fields(model_filename)
    
    form_content = ""
    for key, value in model_fields.items():
        form_content += "    <div class='form-group'>\n"
        form_content += f"        <label for='{key}'> { key.capitalize() }: </label>\n"
        form_content += "        {{ form."+key+" }}\n"
        form_content += '''
                    {% if form.'''+key+'''.errors %}
                        {% for error in form.'''+key+'''.errors %}
                            <span class="text-danger">
                                {{error}}
                            </span>
                        {% endfor %}
                    {% endif %}
        '''
        form_content += "    </div>"
        
    

        
    index_content = '''<form action="" method="post">
                            {% csrf_token %}

                            {% if '''+ model_name.lower() +''' %}
                                <input type="hidden" name="_method" value="PUT" >
                            {% endif %}
                            '''+form_content+'''
                            
                            <div>
                            {% if '''+ model_name.lower() +''' %}
                                <button class="btn btn-success my-2">Update</button>
                            {% else %}
                                <button class="btn btn-success my-2">Create</button>
                            {% endif %}
                                
                            <a href="{% url '''+ model_name.lower() +'''_index %}" class="btn btn-danger my-2">Cancel</a>
                        </div>
                        </form>
                        {% block scripts %}
                        <script src="https://cdn.ckeditor.com/ckeditor5/40.2.0/classic/ckeditor.js"></script>

                        <script>
                            $(document).ready(function() {
                                $('select').select2();
                            });

                        </script>
                        <script>
                            const editors = document.querySelectorAll('textarea')

                            editors.forEach(editor => {
                                editor.removeAttribute('required')
                                ClassicEditor
                                    .create(editor)
                                    .catch( error => {
                                        console.error( error );
                                    } );
                                
                            });
                        </script>
                        {% endblock %}
                        '''

    with open(template_folder / f"{model_name.lower()}_form.html", "w") as index_file:
        index_file.write(index_content)
     

def generate_templates(model_name, app_name):
    
    template_folder = Path(f"{app_name}/templates/{app_name}/{get_plural(model_name.lower())}")

    if not template_folder.exists():
        template_folder.mkdir(parents=True)

    # paginator template
    create_view_paginator(model_name, app_name)

    # Index template
    create_view_index(model_name, app_name)

    # Detail template
    create_view_show(model_name, app_name)
        
    # Edit template
    create_view_edit(model_name, app_name)
        
    # Edit template
    create_view_create(model_name, app_name)
        
    # Edit template
    create_view_form(model_name, app_name)
        
    print(f"Templates for {model_name} generated in {template_folder}!")
    
    
if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Générer une vue Django pour un modèle.")
    parser.add_argument("app_name", help="Nom de l'application dans laquelle vous souhaitez générer la vue.")
    parser.add_argument("model_name", help="Nom du modèle pour lequel vous souhaitez générer la vue.")
    args = parser.parse_args()

    try:
        generate_templates(model_name=args.model_name, app_name=args.app_name)
    except LookupError:
        print("L'application spécifiée est introuvable.")



from setuptools import setup, find_packages
from io import open
from os import path
import pathlib


# The directory containing this file
HERE = pathlib.Path(__file__).parent
# The text of the README file
README = (HERE / "README.md").read_text(encoding="utf-8")




setup(
    name='mudey-django',
    version='2.3',
    packages=find_packages(),
    description='CLI Django',
    author='Espero-Soft Informatiques',
    author_email='contact@espero-soft.com',
    long_description=README,
    long_description_content_type='text/markdown',
    # url='lien_vers_le_code_source',
    entry_points={
        'console_scripts': [
            'mudey-django = package.module:main',
        ],
    },
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'annotated-types>=0.6.0',
        'Django>=5.0',
        'inflect>=7.0.0',
        'questionary>=2.0.1',
        'colorama>=0.4.6'
    ],
)



import argparse
import re
from django import forms
from pathlib import Path



field_widgets = {
    'DateField': "forms.DateInput(attrs={'class': 'form-control datepicker'})",
    'DateTimeField': "forms.DateTimeInput(attrs={'class': 'form-control datetimepicker'})",
    'CharField': "forms.TextInput(attrs={'class': 'form-control custom-text-input'})",
    'EmailField': "forms.EmailInput(attrs={'class': 'form-control custom-email-input'})",
    'BooleanField': "forms.CheckboxInput(attrs={'class': 'form-control custom-checkbox'})",
    'IntegerField': "forms.NumberInput(attrs={'class': 'form-control custom-number-input'})",
    'FloatField': "forms.NumberInput(attrs={'class': 'form-control custom-float-input'})",
    'URLField': "forms.URLInput(attrs={'class': 'form-control custom-url-input'})",
    'FileField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-file-input'})",
    'ImageField': "forms.ClearableFileInput(attrs={'class': 'form-control custom-image-input'})",
    'TextField': "forms.Textarea(attrs={'class': 'form-control custom-textarea'})",
    'SlugField': "forms.TextInput(attrs={'class': 'form-control custom-slug-input'})",
    'ChoiceField': "forms.Select(attrs={'class': 'form-control custom-select'})",
    'ModelChoiceField': "forms.Select(attrs={'class': 'form-control custom-model-select'})",
    'TimeField': "forms.TimeInput(attrs={'class': 'form-control custom-time-input'})",
    'DecimalField': "forms.NumberInput(attrs={'class': 'form-control custom-decimal-input'})",
}


def parse_model_fields(file_path):
    field_pattern = re.compile(r'^\s*(\w+)\s*=\s*models\.(\w+)\(', re.MULTILINE)
    fields = {}

    with open(file_path, 'r') as file:
        content = file.read()
        matches = field_pattern.finditer(content)

        for match in matches:
            field_name = match.group(1)
            field_type = match.group(2)
            fields[field_name] = field_type

    return fields


def generate_form(app_name, model_name):
    # Chemin du dossier des formulaires dans l'application spécifiée
    form_folder = Path(f"{app_name}/forms")

    if not form_folder.exists():
        form_folder.mkdir(parents=True)

    # Nom du fichier pour le formulaire
    form_filename = form_folder / f"{model_name}Form.py"

  
    if form_filename.exists():
        user_input = input(f"Le fichier '{form_filename}' existe déjà. Voulez-vous l'écraser ? (O/n): ")
        if user_input.lower() != 'o':
            print("Annulation de la création du formulaire.")
            return

    # Génération du contenu du formulaire Django
    model_filename = f"{app_name}/models/{model_name}.py"
    model_fields = parse_model_fields(model_filename)
    
    form_content = f"from django import forms\nfrom {app_name}.models.{model_name} import {model_name}\n\n"
    form_content += f"class {model_name}Form(forms.ModelForm):\n"
    form_content += f"    class Meta:\n"
    form_content += f"        model = {model_name}\n"
    form_content += f"        fields = {tuple(model_fields.keys())}\n\n"

    # Ajout des widgets aux champs spécifiques du modèle
    # print(model_fields)
    form_content += "        widgets = {\n"
    for field_name, field_type in model_fields.items():
        field_type = field_type
        if field_type in field_widgets:
            form_content += f"            '{field_name}' : forms.{field_widgets[field_type]},\n"
         
    form_content += "        }\n"   
    # Écriture du contenu dans le fichier du formulaire
    with open(form_filename, "w") as form_file:
        form_file.write(form_content)

    print(f"Le formulaire {model_name}Form a été créé dans {form_folder} !")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Générer un formulaire Django interactif.")
    parser.add_argument("app_name", help="Nom de l'application dans laquelle vous souhaitez générer le formulaire.")
    parser.add_argument("model_name", help="Nom du modèle pour lequel vous souhaitez générer le formulaire.")
    args = parser.parse_args()

    try:
        generate_form(model_name=args.model_name, app_name=args.app_name)
    except LookupError:
        print("L'application spécifiée est introuvable.")
